Entry class

The PO file entry representation.

https://www.gnu.org/software/gettext/manual/html_node/PO-Files.html

#  translator-comments
#. extracted-comments
#: reference…
#, flag…
#| msgid previous-untranslated-string
msgid untranslated-string
msgstr translated-string

It's created only for the purpose of extracting strings from Dart code, so we don't support all format features, such as the previous msgid.

Constructors

Entry({List<String> translatorComment = const [], List<String> extractedComment = const [], List<String> flags = const [], String msgid = "", String? msgidPlural, String? msgctxt, String msgstr = "", List<String> msgstrList = const [], List<Reference> references = const [], required ExtractSettings settings})
Entry.fromString(ExtractSettings settings, String value)
Parses the string representation of Entry
factory

Properties

extractedComment → List<String>
final
flags → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
indentTranslatorComment ↔ bool
getter/setter pair
msgctxt ↔ String?
getter/setter pair
msgid ↔ String
getter/setter pair
msgidPlural ↔ String?
getter/setter pair
msgstr ↔ String
getter/setter pair
msgstrList → List<String>
final
references → List<Reference>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → ExtractSettings
final
translatorComment → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Generates the string representation of this Entry.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

removeQuotes(String value) → String
Trims quotes (the first and the last character).
toMultiLine(ExtractSettings settings, String prefix, String value) → String
Converts single line value into prefixed multi line PO string.