ExtractSettings class

Constructors

ExtractSettings()

Properties

copyrightHolder ↔ String?
getter/setter pair
encoding ↔ Encoding
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
packageName ↔ String?
getter/setter pair
packageVersion ↔ String?
getter/setter pair
reportBugsTo ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String?
getter/setter pair
textWidth ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited