Extractor class

Handles string extraction from files.

Constructors

Extractor(List<File> files, ExtractSettings settings)

Properties

files → List<File>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → ExtractSettings
final

Methods

extractCatalog() → Catalog
extractEntries() → List<Entry>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited