Source class abstract interface

The source file representation.

It has an extract method, that returns a list of Entrys extracted from the file. It can be used later to add to a Catalog.

Implementers

Properties

file → File
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extract(ExtractSettings settings) → List<Entry>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited